main: rename 'real_main()' to 'model_main()'
[c11tester.git] / main.cc
diff --git a/main.cc b/main.cc
index 215a2197d35e91fa29cf65b869a292165be4a9ad..853654ccd35626c8410842f15419b265accd2dbb 100644 (file)
--- a/main.cc
+++ b/main.cc
 
 static void param_defaults(struct model_params * params) {
        params->maxreads = 0;
+       params->maxfuturedelay = 100;
+       params->fairwindow = 0;
+       params->enabledcount = 1;
 }
 
-static void print_usage() {
+static void print_usage(struct model_params *params) {
        printf(
 "Usage: <program name> [MC_OPTIONS] -- [PROGRAM ARGUMENTS]\n"
 "\n"
 "Options:\n"
 "-h                    Display this help message and exit\n"
-"-m                    Maximum times a thread can read from the same write while other writes exist\n"
-"--                    Program arguments follow.\n\n");
+"-m                    Maximum times a thread can read from the same write\n"
+"                      while other writes exist. Default: %d\n"
+"-s                    Maximum actions that the model checker will wait for\n"
+"                      a write from the future past the expected number of\n"
+"                      actions. Default: %d\n"
+"-f                    Specify a fairness window in which actions that are\n"
+"                      enabled sufficiently many times should receive\n"
+"                      priority for execution. Default: %d\n"
+"-e                    Enabled count. Default: %d\n"
+"--                    Program arguments follow.\n\n",
+params->maxreads, params->maxfuturedelay, params->fairwindow, params->enabledcount);
        exit(EXIT_SUCCESS);
 }
 
 static void parse_options(struct model_params *params, int *argc, char ***argv) {
-       const char *shortopts = "hm:";
+       const char *shortopts = "hm:s:f:e:";
        int opt;
        bool error = false;
        while (!error && (opt = getopt(*argc, *argv, shortopts)) != -1) {
                switch (opt) {
                case 'h':
-                       print_usage();
+                       print_usage(params);
+                       break;
+               case 's':
+                       params->maxfuturedelay = atoi(optarg);
+                       break;
+               case 'f':
+                       params->fairwindow = atoi(optarg);
+                       break;
+               case 'e':
+                       params->enabledcount = atoi(optarg);
                        break;
                case 'm':
                        params->maxreads = atoi(optarg);
@@ -50,14 +71,14 @@ static void parse_options(struct model_params *params, int *argc, char ***argv)
        (*argv) += optind;
 
        if (error)
-               print_usage();
+               print_usage(params);
 }
 
 int main_argc;
 char **main_argv;
 
-/** The real_main function contains the main model checking loop. */
-static void real_main() {
+/** The model_main function contains the main model checking loop. */
+static void model_main() {
        thrd_t user_thread;
        struct model_params params;
 
@@ -89,12 +110,12 @@ static void real_main() {
 
 /**
  * Main function.  Just initializes snapshotting library and the
* snapshotting library calls the real_main function.
  */
 int main(int argc, char ** argv) {
        main_argc = argc;
        main_argv = argv;
 
        /* Let's jump in quickly and start running stuff */
-       initSnapShotLibrary(10000, 1024, 1024, 1000, &real_main);
+       initSnapshotLibrary(10000, 1024, 1024, 4000, &model_main);
 }
@@ -89,12 +110,12 @@ static void real_main() {
 /**
  * Main function.  Just initializes snapshotting library and the
- * snapshotting library calls the real_main function.
+ * snapshotting library calls the model_main function.
  */
 int main(int argc, char ** argv) {